//Source file: Amount.java
//Date: December 2005
//Charging Interfaces and Data Types for 3GPP TS 29.198-12 V6.4.0

package org.csapi.jr.se.cs;

/**
 * Defines the Sequence of Data Elements that define an amount in integers as 'Number  10 ^ Exponent' 
(that is if Number = 6543 and Exponent = -2 then the amount is 65,43). This representation avoids unwanted rounding off.
 * 
 */
public final class Amount implements java.io.Serializable {

    private int number;
    private int exponent;

    /**
     * Creates a new Amount instance.
     */
    public Amount () {}

    /**
     * Creates a new Amount instance.
     * @param _number   
     * @param _exponent   
     */
    public Amount (int _number, int _exponent) {

        this.number = _number;
        this.exponent = _exponent;
    }

    /**
     * This method returns a number.
     * 
     * @return a int value
     */
    public int getNumber() {
        return number;
    }

    /**
     * This method returns a exponent.
     * 
     * @return a int value
     */
    public int getExponent() {
        return exponent;
    }


    /**
     * This method sets a number.
     */ 
    public void setNumber(int number) {
        this.number = number;
    }

    /**
     * This method sets a exponent.
     */ 
    public void setExponent(int exponent) {
        this.exponent = exponent;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof Amount)) {
            return false;
        } 
        Amount amount = (Amount) o;
        if(!(this.number == amount.number)) {
            return false;
        }
        if(!(this.exponent == amount.exponent)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // Amount

