//Source file: AppInformationType.java
//Date: December 2005
//Charging Interfaces and Data Types for 3GPP TS 29.198-12 V6.4.0

package org.csapi.jr.se.cs;

/**
 * Defines the possible information items.
 *
 */
public final class AppInformationType implements java.io.Serializable {

    private int _value;
    private static int _size = 1;
    private static AppInformationType[] _array = new AppInformationType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private AppInformationType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * The information item contains a timestamp.
     */
    public static final int _APP_INF_TIMESTAMP =  0;

    /**
     * The information item contains a timestamp.
     */
    public static final AppInformationType APP_INF_TIMESTAMP = new AppInformationType(_APP_INF_TIMESTAMP);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved AppInformationType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the AppInformationType object
     */
    public String getValueText() {
        switch (_value) {
            case _APP_INF_TIMESTAMP:
                return "APP_INF_TIMESTAMP";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 0
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static AppInformationType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof AppInformationType)) {
            return false;
        }
        AppInformationType appInformationType = (AppInformationType) o; 
        if(!(this.getValue() == appInformationType.getValue())) {
            return false;
        }
        if (this.hashCode() != appInformationType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // AppInformationType

