//Source file: ChargingParameterValue.java
//Date: December 2005
//Charging Interfaces and Data Types for 3GPP TS 29.198-12 V6.4.0

package org.csapi.jr.se.cs;

/**
 * Defines the Tagged Choice of Data Elements that identify a charging parameter.
 *
 */
public final class ChargingParameterValue implements java.io.Serializable {

    private ChargingParameterValueType _discriminator = null;
    private java.lang.Object _object;

    /**
     * Creates a new ChargingParameterValue.
     * Tagged choice of data elements always have empty constructors
     */ 
    public ChargingParameterValue() {}

    /**
     * This method returns the discriminator.
     * 
     * @return a ChargingParameterValueType value 
     * @exception InvalidUnionAccessorException if an error occurs 
     */ 
    public ChargingParameterValueType getDiscriminator() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator == null) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return _discriminator;
    }

    /**
     * This method returns a IntValue
     * 
     * @return  a int value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public int getIntValue() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != ChargingParameterValueType.CHS_PARAMETER_INT32) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.Integer) _object).intValue());
    }

    /**
     * This method sets a IntValue
     * 
     * @param value a int value
     */
    public void setIntValue(int value) {
        _discriminator = ChargingParameterValueType.CHS_PARAMETER_INT32;
        _object = new java.lang.Integer(value);
    }

    /**
     * This method returns a FloatValue
     * 
     * @return  a float value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public float getFloatValue() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != ChargingParameterValueType.CHS_PARAMETER_FLOAT) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.Float) _object).floatValue());
    }

    /**
     * This method sets a FloatValue
     * 
     * @param value a float value
     */
    public void setFloatValue(float value) {
        _discriminator = ChargingParameterValueType.CHS_PARAMETER_FLOAT;
        _object = new java.lang.Float(value);
    }

    /**
     * This method returns a StringValue
     * 
     * @return  a java.lang.String value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public java.lang.String getStringValue() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != ChargingParameterValueType.CHS_PARAMETER_STRING) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.String) _object));
    }

    /**
     * This method sets a StringValue
     * 
     * @param value a java.lang.String value
     */
    public void setStringValue(java.lang.String value) {
        _discriminator = ChargingParameterValueType.CHS_PARAMETER_STRING;
        _object = value;
    }

    /**
     * This method returns a BooleanValue
     * 
     * @return  a boolean value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public boolean getBooleanValue() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != ChargingParameterValueType.CHS_PARAMETER_BOOLEAN) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return (((java.lang.Boolean) _object).booleanValue());
    }

    /**
     * This method sets a BooleanValue
     * 
     * @param value a boolean value
     */
    public void setBooleanValue(boolean value) {
        _discriminator = ChargingParameterValueType.CHS_PARAMETER_BOOLEAN;
        _object = new java.lang.Boolean(value);
    }

    /**
     * This method returns a OctetValue
     * 
     * @return  a byte[] value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public byte[] getOctetValue() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != ChargingParameterValueType.CHS_PARAMETER_OCTETSET) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return ((byte[]) _object);
    }

    /**
     * This method sets a OctetValue
     * 
     * @param value a byte[] value
     */
    public void setOctetValue(byte[] value) {
        _discriminator = ChargingParameterValueType.CHS_PARAMETER_OCTETSET;
        _object = value;
    }


    /**
     * This method will receive the discriminator as a parameter and will set _object to null
     * 
     * @param discriminator a ChargingParameterValueType value 
     */ 
    public void setUndefined(ChargingParameterValueType discriminator) {
        _discriminator = discriminator;
        _object = null;
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) {
            return false;
        }
        if(!(o instanceof ChargingParameterValue)) {
            return false;
        } else {
            ChargingParameterValue chargingParameterValue= (ChargingParameterValue)o;
            if(!(this._object.equals(chargingParameterValue._object))){
                return false;
            } else {
                if(!(this._discriminator.equals(chargingParameterValue._discriminator))){
                    return false;
                }
            }
            if (this.hashCode() != o.hashCode()) {
                return false;
            }
            return true;
        }
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // ChargingParameterValue

